@@ -23,6 +23,7 @@ public:
 	virtual bool on_search_key_pressed(std::string search_str) = 0;
 	virtual bool on_search_next() = 0;
 	virtual std::string* get_last_search_string() = 0;
+	virtual ~search_caller_interface() = default;
 };
 
 class sidemenu_list_entry
@@ -86,10 +87,10 @@ public:
 	//
 	// Returns false if this chart doesn't support returning the current position
 	//
-	virtual bool get_position(OUT int32_t* pos, 
-		OUT int32_t* totlines, 
-		OUT float* percent,
-		OUT bool* truncated) = 0;
+	virtual bool get_position(int32_t* pos, 
+		int32_t* totlines, 
+		float* percent,
+		bool* truncated) = 0;
 };
 
 class curses_table_column_info
@@ -97,12 +98,13 @@ class curses_table_column_info
 public:	
 	curses_table_column_info()
 	{
+		m_size = -1;
 	}
 
 	//
 	// Use -1 as size for autosize
 	//
-	curses_table_column_info(IN filtercheck_field_info* info, int32_t size)
+	curses_table_column_info(filtercheck_field_info* info, int32_t size)
 	{
 		m_info = *info;
 		m_size = size;
@@ -194,7 +196,7 @@ public:
 	chisel_table_action handle_input(int ch);
 	void populate_sidemenu();
 	void reset();
-	bool get_position(OUT int32_t* pos, OUT int32_t* totlines, OUT float* percent, OUT bool* truncated);
+	bool get_position(int32_t* pos, int32_t* totlines, float* percent, bool* truncated);
 	std::string* get_last_search_string();
 	int8_t get_offset(int32_t* x, int32_t* y); 
 	int8_t scroll_to(int32_t x, int32_t y);
@@ -212,7 +214,7 @@ private:
 	ctext* m_ctext;
 	sinsp_cursesui* m_parent;
 	sinsp* m_inspector;
-	sinsp_filter* m_filter;
+	std::unique_ptr<sinsp_filter> m_filter;
 	uint32_t n_prints;
 	bool m_paused;
 	curses_table_sidemenu* m_sidemenu;
